@@ -304,6 +304,7 @@ char *GetMIMEDescription()
 		    "video/x-ms-wmv:wmv,*:Microsoft WMV video;"
 		    "audio/x-ms-wmv:wmv,*:Windows Media;"
 		    "video/x-ms-wmp:wmp,*:Windows Media;"
+		    "application/x-ms-wmp:wmp,*:Windows Media;"
 		    "video/x-ms-wvx:wvx,*:Windows Media;"
 		    "audio/x-ms-wax:wax,*:Windows Media;"
 		    "audio/x-ms-wma:wma,*:Windows Media;"
@@ -548,8 +549,13 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 	    }
 
 	    if (parameters->argn[i] == NULL || parameters->argv[i] == NULL) {
-		break;
-	    }
+		// break;
+		// NOTE: for compatability reasons, the NPAPI places a fake
+		// parameter with a null value in the list between parameters
+		// set in the actual <embed> or <object> node and ones set as
+		// <param> nodes
+		continue;	    
+            }
 
 	    if (strncasecmp(parameters->argn[i], "debug", 5) == 0) {
 		lowercase(parameters->argv[i]);
@@ -635,6 +641,23 @@ void New(nsPluginInstance * instance, nsPluginCreateData * parameters)
 		instance->state = STATE_HAVEURL;
 	    }
 
+            if (strncasecmp(parameters->argn[i], "autohref", 8) == 0) {
+
+		lowercase(parameters->argv[i]);
+		if (DEBUG)
+		    printf("argv[i]=%s\n", parameters->argv[i]);
+
+		if (strstr(parameters->argv[i], "true")
+		    || strstr(parameters->argv[i], "yes")
+		    || strstr(parameters->argv[i], "1")) {
+		    instance->autohref = 1;
+		} else {
+		    instance->autohref = 0;
+		}
+		if (DEBUG)
+		    printf("autohref=%i\n", instance->autohref);
+	    }
+
 	    if (strncasecmp(parameters->argn[i], "height", 6) == 0) {
 		if (strstr(parameters->argv[i], "%") == NULL)
 		    sscanf(parameters->argv[i], "%i",
