@@ -213,7 +213,7 @@ FILE *mypopen(char **argv, pid_t * pid, int *control,
 
     } else {
 	// setup signal handler for child
-	signal(SIGCHLD, sig_child);
+	// signal(SIGCHLD, sig_child);
 	sigemptyset(&newmask);
 	sigaddset(&newmask, SIGCHLD);
 	sigaddset(&newmask, SIGTERM);
@@ -404,8 +404,8 @@ void SetupPlayer(nsPluginInstance * instance, XEvent * event)
 	    if (GTK_IS_WIDGET(instance->drawing_area)) {
 		gtk_widget_show(instance->drawing_area);
 		gtk_widget_set_usize(instance->drawing_area, 1, 1);
-		while (gtk_events_pending())
-		    gtk_main_iteration();
+//		while (gtk_events_pending())
+//		    gtk_main_iteration();
 
 	    }
 #ifdef GTK2_ENABLED
@@ -1746,7 +1746,7 @@ void *playPlaylist(void *td)
 		 i);
 
 	// if the play count is exactly 1 then tell mplayer to loop continuously and to use the same frame buffer (should eliminate blinking)
-	if (i == 1 || local_list->loop == 1) {
+	if (i == 1 || local_td->instance->loop == 1) {
 	    loop_single = 1;
 	    local_td->argv[argc++] = strdup("-loop");
 	    snprintf(buffer, 32, "%i", local_td->instance->loop);
@@ -2085,8 +2085,8 @@ void *playPlaylist(void *td)
 	    pthread_testcancel();
 #ifdef GTK_ENABLED
 
-		while (gtk_events_pending())
-		    gtk_main_iteration();
+//		while (gtk_events_pending())
+//		    gtk_main_iteration();
 
 #endif
 
