@@ -167,6 +167,7 @@ mInitialized(FALSE), mScriptablePeer(NULL), mControlsScriptablePeer(NULL)
     url = NULL;
     fname = NULL;
     href = NULL;
+    autohref = 0;
     lastmessage = (char *) NPN_MemAlloc(sizeof(char) * 1024);
     memset(lastmessage, '\0', 1);
     mode = 0;
@@ -346,6 +347,7 @@ mInitialized(FALSE), mScriptablePeer(NULL), mControlsScriptablePeer(NULL)
     textdomain("mplayerplug-in");
     bind_textdomain_codeset("mplayerplug-in", "utf-8");
 #endif
+    time(&lastOutput);
 }
 
 nsPluginInstance::~nsPluginInstance()
@@ -1042,18 +1044,21 @@ NPError nsPluginInstance::SetWindow(NPWindow * aWindow)
 	    if (!hidestatus)
 		gtk_widget_show(GTK_WIDGET(progress_bar));
 #ifdef GTK2_ENABLED
-	    gtk_widget_set_size_request(GTK_WIDGET(progress_bar),
-					window_width - 20, 15);
-	    gtk_widget_set_size_request(GTK_WIDGET(status),
-					window_width,
-					window_height - 31);
+	    if (window_width > 20)
+		gtk_widget_set_size_request(GTK_WIDGET(progress_bar),
+					    window_width - 20, 15);
+	    if (window_height > 31)
+		gtk_widget_set_size_request(GTK_WIDGET(status),
+					    window_width,
+					    window_height - 31);
 #endif
 #ifdef GTK1_ENABLED
-	    gtk_widget_set_usize(GTK_WIDGET(progress_bar),
-				 aWindow->width - 20, 15);
-	    gtk_widget_set_usize(GTK_WIDGET(status),
-				 aWindow->width,
-				 aWindow->height - 31);
+	    if (aWindow->width > 20)
+		gtk_widget_set_usize(GTK_WIDGET(progress_bar),
+				     aWindow->width - 20, 15);
+	    if (aWindow->height > 31)
+		gtk_widget_set_usize(GTK_WIDGET(status),
+				     aWindow->width, aWindow->height - 31);
 #endif
 	}
 
@@ -1214,16 +1219,22 @@ NPError nsPluginInstance::SetWindow(NPWindow * aWindow)
 	if (!hidestatus)
 	    gtk_widget_show(GTK_WIDGET(status));
 #ifdef GTK2_ENABLED
-	gtk_widget_set_size_request(GTK_WIDGET(status),
-				    window_width - 20, window_height - 25);
-	gtk_widget_set_size_request(GTK_WIDGET(gtkwidget),
-				    window_width, window_height);
+	if (window_width > 20 && window_height > 25)
+	    gtk_widget_set_size_request(GTK_WIDGET(status),
+					window_width - 20,
+					window_height - 25);
+
+	if (window_width > 0 && window_height > 0)
+	    gtk_widget_set_size_request(GTK_WIDGET(gtkwidget),
+					window_width, window_height);
 
 #endif
 #ifdef GTK1_ENABLED
-	gtk_widget_set_usize(GTK_WIDGET(status),
-			     window_width - 20, window_height - 25);
-	gtk_widget_set_usize(GTK_WIDGET(gtkwidget),
+	if (window_width > 20 && window_height > 25)
+	    gtk_widget_set_usize(GTK_WIDGET(status),
+				 window_width - 20, window_height - 25);
+	if (window_width > 0 && window_height > 0)
+	    gtk_widget_set_usize(GTK_WIDGET(gtkwidget),
 			     window_width, window_height);
 #endif
 	if (panel_drawn == 1) {
@@ -1277,19 +1288,21 @@ NPError nsPluginInstance::SetWindow(NPWindow * aWindow)
 	    gtk_fixed_move(GTK_FIXED(fixed_container),
 			   GTK_WIDGET(progress_bar),
 			   10, window_height - 31);
-
-	    gtk_widget_set_usize(GTK_WIDGET(progress_bar),
-				 window_width - 20, 15);
+	    if (window_width > 20 && window_height > 0)
+		gtk_widget_set_usize(GTK_WIDGET(progress_bar),
+				     window_width - 20, 15);
 	}
 
 	if (GTK_IS_WIDGET(drawing_area) && (movie_width > 0)
 	    && (movie_height > 0) && mode == NP_EMBED) {
 	    if (showcontrols) {
-		gtk_widget_set_usize(GTK_WIDGET(drawing_area),
-				     window_width, window_height - 16);
+		if (window_width > 0 && window_height > 16)
+		    gtk_widget_set_usize(GTK_WIDGET(drawing_area),
+					 window_width, window_height - 16);
 	    } else {
-		gtk_widget_set_usize(GTK_WIDGET(drawing_area),
-				     window_width, window_height);
+		if (window_width > 0 && window_height > 0)
+		    gtk_widget_set_usize(GTK_WIDGET(drawing_area),
+					 window_width, window_height);
 	    }
 	}
 
@@ -1992,72 +2005,80 @@ int32 nsPluginInstance::Write(NPStream * stream, int32 offset, int32 len,
 			n->retrieved = 1;
 		    }
 		}
-		if (mode == NP_EMBED && noembed == 0 && fullscreen == 0) {
-		    if (state < STATE_PLAYING) {
+
+		if (difftime(time(NULL), lastOutput) > 0.5) {
+
+		    if (mode == NP_EMBED && noembed == 0
+			&& fullscreen == 0) {
+			if (state < STATE_PLAYING) {
 #ifdef X_ENABLED
-			DrawUI(widget, this, message,
-			       0,
-			       (int) ((currdownload /
-				       (maxdownload * 1.0)) * 100));
+			    DrawUI(widget, this, message,
+				   0,
+				   (int) ((currdownload /
+					   (maxdownload * 1.0)) * 100));
 #endif
 #ifdef GTK_ENABLED
-			if (GTK_IS_WIDGET(progress_bar)
-			    && maxdownload != 0) {
-			    if (movie_width == 0 && movie_height == 0) {
-				gtk_progress_bar_update(progress_bar,
-							((currdownload *
-							  1.0) /
-							 (maxdownload *
-							  1.0)));
-				if (!hidestatus)
-				    gtk_widget_show(GTK_WIDGET
-						    (progress_bar));
-				gtk_widget_queue_draw(GTK_WIDGET
-						      (progress_bar));
+			    if (GTK_IS_WIDGET(progress_bar)
+				&& maxdownload != 0) {
+				if (movie_width == 0 && movie_height == 0) {
+				    gtk_progress_bar_update(progress_bar,
+							    ((currdownload
+							      * 1.0) /
+							     (maxdownload *
+							      1.0)));
+				    if (!hidestatus)
+					gtk_widget_show(GTK_WIDGET
+							(progress_bar));
+				    gtk_widget_queue_draw(GTK_WIDGET
+							  (progress_bar));
+				}
 			    }
-			}
-			if (status != NULL) {
-			    gtk_label_set_text(status, message);
-			    if (!hidestatus)
-				gtk_widget_show(GTK_WIDGET(status));
-			    gtk_widget_queue_draw(GTK_WIDGET(status));
-			}
-#endif
-		    }
-		} else {
-		    if (fullscreen == 0) {
-#ifdef X_ENABLED
-			DrawUI(widget, this, message,
-			       0,
-			       (int) ((currdownload /
-				       (maxdownload * 1.0)) * 100));
-#endif
-#ifdef GTK_ENABLED
-			if (GTK_IS_WIDGET(progress_bar)
-			    && maxdownload != 0) {
-			    if (movie_width == 0 && movie_height == 0) {
-				gtk_progress_bar_update(progress_bar,
-							((currdownload *
-							  1.0) /
-							 (maxdownload *
-							  1.0)));
-				if (!hidestatus)
-				    gtk_widget_show(GTK_WIDGET
-						    (progress_bar));
-				gtk_widget_queue_draw(GTK_WIDGET
-						      (progress_bar));
-			    }
-			}
-			if (status != NULL) {
-			    if (state < STATE_PLAYING) {
+			    if (status != NULL) {
 				gtk_label_set_text(status, message);
 				if (!hidestatus)
 				    gtk_widget_show(GTK_WIDGET(status));
 				gtk_widget_queue_draw(GTK_WIDGET(status));
 			    }
-			}
 #endif
+			}
+		    } else {
+			if (fullscreen == 0) {
+#ifdef X_ENABLED
+			    DrawUI(widget, this, message,
+				   0,
+				   (int) ((currdownload /
+					   (maxdownload * 1.0)) * 100));
+#endif
+#ifdef GTK_ENABLED
+			    if (GTK_IS_WIDGET(progress_bar)
+				&& maxdownload != 0) {
+				if (movie_width == 0 && movie_height == 0) {
+				    gtk_progress_bar_update(progress_bar,
+							    ((currdownload
+							      * 1.0) /
+							     (maxdownload *
+							      1.0)));
+				    if (!hidestatus)
+					gtk_widget_show(GTK_WIDGET
+							(progress_bar));
+				    gtk_widget_queue_draw(GTK_WIDGET
+							  (progress_bar));
+				}
+			    }
+			    if (status != NULL) {
+				if (state < STATE_PLAYING) {
+				    gtk_label_set_text(status, message);
+				    if (!hidestatus)
+					gtk_widget_show(GTK_WIDGET
+							(status));
+				    gtk_widget_queue_draw(GTK_WIDGET
+							  (status));
+				}
+			    }
+#endif
+			}
 		    }
+		    time(&lastOutput);
 		}
 	    }
 
@@ -2476,6 +2497,8 @@ void nsPluginInstance::SetFilename(const char *filename)
     threadsignaled = 0;
     // reset the list
 */
+    if (filename == NULL)
+	return;
 
     if (DEBUG)
 	printf("threadsetup = %i, threadsignaled = %i\n", threadsetup,
@@ -3187,7 +3210,7 @@ void nsPluginInstance::PlaylistAppend(const char *item)
 	    tail = tail->next;
     }
     fullyQualifyURL(this, (char *) item, localurl);
-    addToList(this, localurl, tail, -1, 0, -1,0);
+    addToList(this, localurl, tail, -1, 0, -1, 0);
     pthread_mutex_unlock(&playlist_mutex);
 }
 
