@@ -57,6 +57,7 @@
 #include <sys/types.h>
 #include <signal.h>
 #include <string.h>
+#include <time.h>
 #ifdef HAVE_GETTEXT
 # include <libintl.h>
 # define _(x) (gettext(x))
@@ -136,6 +137,7 @@ class nsPluginInstance:public nsPluginInstanceBase {
     char *url;
     char *fname;
     char *href;
+    int autohref;
     char *lastmessage;
     uint16 mode;
     uint32 window_width;
@@ -402,6 +404,8 @@ class nsPluginInstance:public nsPluginInstanceBase {
     // JavaScript State
     int paused;
     int js_state;
+
+    time_t lastOutput;
 };
 
 #endif				// __PLUGIN_H__
